# pytorch-sidu
SIDU: SImilarity Difference and Uniqueness method for explainable AI

This is a Pytorch implmentation of the SIDU method for generating saliency maps. 

## Installation

```
pip install pytorch-sidu
```


## License

This project is licensed under the GNU General Public License 3.0. For more details, see the LICENSE file in the root directory of this project or check out the GNU General Public License 3.0. [here](https://www.gnu.org/licenses/gpl-3.0.html)